@@ -42,7 +42,7 @@ dGSEAview <- function(eTerm, which_sample=1, top_num=10, sortBy=c("adjp","gadjp"
     
     sortBy <- match.arg(sortBy)
     
-    if(is.null(top_num) | top_num > length(eTerm$set_info$setID)){
+    if( is.null(top_num) | length(top_num > length(eTerm$set_info$setID))==0 ){
         top_num <- length(eTerm$set_info$setID)
     }
     
