@@ -1,25 +1,25 @@
-#' Function to setup the pipeline for finding maximum-scoring module from an input graph and the signficance imposed on its nodes
+#' Function to setup the pipeline for finding maximum-scoring subgraph from an input graph and the signficance imposed on its nodes
 #'
-#' \code{dNetPipeline} is supposed to finish ab inito maximum-scoring module identification for the input graph with the node information on the significance (p-values). It returns an object of class "igraph" or "graphNEL". 
+#' \code{dNetPipeline} is supposed to finish ab inito maximum-scoring subgraph identification for the input graph with the node information on the significance (p-value or fdr). It returns an object of class "igraph" or "graphNEL". 
 #'
 #' @param g an object of class "igraph" or "graphNEL"
-#' @param pval a vector containing input p-values. For each element, it must have the name that could be mapped onto the input graph. Also, the names in input "pval" should contain all those in the input graph "g", but the reverse is not necessary
+#' @param pval a vector containing input p-values (or fdr). For each element, it must have the name that could be mapped onto the input graph. Also, the names in input "pval" should contain all those in the input graph "g", but the reverse is not necessary
 #' @param method the method used for the transformation. It can be either "pdf" for the method based on the probability density function of the fitted model, or "cdf" for the method based on the cumulative distribution function of the fitted model
-#' @param fdr the given FDR threshold. By default, it is set to NULL, meaning there is no constraint. If given, those p-values with the FDR below this are considered significant and thus scored positively. Instead, those p-values with the FDR above this given FDR are considered insigificant and thus scored negatively
-#' @param nsize the desired number of nodes constrained to the resulting module. It is not nulll, a wide range of FDR will be scanned to find the FDR threshold leading to the desired number of nodes in the resulting module. Notably, the given FDR threshold will be overwritten. 
+#' @param significance.threshold the given significance threshold. By default, it is set to NULL, meaning there is no constraint. If given, those p-values below this are considered significant and thus scored positively. Instead, those p-values above this given significance threshold are considered insigificant and thus scored negatively
+#' @param nsize the desired number of nodes constrained to the resulting subgraph. It is not nulll, a wide range of significance thresholds will be scanned to find the optimal significance threshold leading to the desired number of nodes in the resulting subgraph. Notably, the given significance threshold will be overwritten by this option. 
 #' @param plot logical to indicate whether the histogram plot, contour plot and scatter plot should be drawn. By default, it sets to false for no plotting
 #' @param verbose logical to indicate whether the messages will be displayed in the screen. By default, it sets to true for display
 #' @return
-#' a module with a maximum score, an object of class "igraph" or "graphNEL"
+#' a subgraph with a maximum score, an object of class "igraph" or "graphNEL"
 #' @note The pipeline sequentially consists of: 
 #' \itemize{
-#' \item{i) \code{\link{dBUMfit}} used to fit the p-value distribution under beta-uniform mixture model.}
-#' \item{ii) if there is the desired number of nodes constrained to the resulting module, a wide range of FDR (including rough stage with large intervals, and finetune stage with smaller intervals) will be scanned to find the FDR threshold to meet the desired number of nodes.}
-#' \item{iii) \code{\link{dBUMscore}} used to calculate the scores according to the fitted BUM and FDR threshold.}
-#' \item{iv) \code{\link{dNetFind}} used to find maximum-scoring module from the input graph and scores imposed on its nodes.}
+#' \item{ia) if the method is either "pdf" or "cdf", \code{\link{dBUMfit}} used to fit the p-value distribution under beta-uniform mixture model, and \code{\link{dBUMscore}} used to calculate the scores according to the fitted BUM and the significance threshold.}
+#' \item{ib) if the method is either "customised", then the user input list of fdr (or p-values) and the significance threshold will be directly used for score transformation by \code{dFDRscore}.}
+#' \item{ii) if there is the desired number of nodes constrained to the resulting subgraph, a wide range of significance thresholds (including rough stage with large intervals, and finetune stage with smaller intervals) will be scanned to find the significance threshold to meet the desired number of nodes.}
+#' \item{iii) \code{\link{dNetFind}} used to find maximum-scoring subgraph from the input graph and scores imposed on its nodes.}
 #' }
 #' @export
-#' @seealso \code{\link{dBUMfit}}, \code{\link{dBUMscore}}, \code{\link{dNetFind}}
+#' @seealso \code{\link{dBUMfit}}, \code{\link{dBUMscore}}, \code{\link{dFDRscore}}, \code{\link{dNetFind}}
 #' @include dBUMfit.r
 #' @examples
 #' # 1) generate an vector consisting of random values from beta distribution
@@ -32,15 +32,18 @@
 #' # 3) produce the induced subgraph only based on the nodes in query
 #' subg <- dNetInduce(g, V(g), knn=0)
 #'
-#' # 4) find maximum-scoring module based on fdr=0.1 threshold
-#' module <- dNetPipeline(g=subg, pval=x, fdr=0.1)
+#' # 4) find maximum-scoring subgraph based on the given significance threshold
+#' # 4a) assume the input is a list of p-values (controlling fdr=0.1)
+#' subgraph <- dNetPipeline(g=subg, pval=x, significance.threshold=0.1)
+#' # 4b) assume the input is a list of customised significance (eg FDR directly)
+#' subgraph <- dNetPipeline(g=subg, pval=x, method="customised", significance.threshold=0.1)
 #' 
 #' \dontrun{
-#' # 5) find maximum-scoring module with the desired node number nsize=20
-#' # module <- dNetPipeline(g=subg, pval=x, nsize=20)
+#' # 5) find maximum-scoring subgraph with the desired node number nsize=20
+#' subgraph <- dNetPipeline(g=subg, pval=x, nsize=20)
 #' }
 
-dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=NULL, plot=F, verbose=T)
+dNetPipeline <- function(g, pval, method=c("pdf","cdf","customised"), significance.threshold=NULL, nsize=NULL, plot=F, verbose=T)
 {
 
     startT <- Sys.time()
@@ -53,9 +56,9 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
     method <- match.arg(method)
     ####################
     
-    if(method!="fdr"){
+    if(method!="customised"){
         if(verbose){
-            message(sprintf("First, fit the p-value distribution under beta-uniform mixture model..."), appendLF=T)
+            message(sprintf("First, fit the input p-value distribution under beta-uniform mixture model..."), appendLF=T)
         }
         ## fit a p-value distribution under beta-uniform mixture model
         if(plot){
@@ -63,18 +66,18 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
         }else{
             fit <- dBUMfit(pval, ntry=1, hist.bum=F, contour.bum=F, verbose=verbose)
         }
-    }else if(method=="fdr"){
+    }else if(method=="customised"){
         if(verbose){
-            message(sprintf("First, consider the fdr distribution"), appendLF=T)
+            message(sprintf("First, consider the input fdr (or p-value) distribution"), appendLF=T)
         }
     }
     
     if(verbose){
-        message(sprintf("Second, determine FDR threshold..."), appendLF=T)
+        message(sprintf("Second, determine the significance threshold..."), appendLF=T)
     }
     ## Determine the final fdr threshold
     if(is.null(nsize)){
-        fdr_final <- fdr
+        fdr_final <- significance.threshold
     }else{
         fdr_final <- NULL
         ####################################
@@ -84,7 +87,7 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
         ## Constraint on the network size
         
         if(verbose){
-            message(sprintf("\tScanning FDR at rough stage..."), appendLF=T)
+            message(sprintf("\tScanning significance threshold at rough stage..."), appendLF=T)
         }
         ## at rough phase
         fdr_rough <- NULL
@@ -92,9 +95,9 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
         for(i in seq(from=floor(log10(min(pval[pval!=0]))),to=0)){
             fdr_test <- 10^i
             
-            if(method!="fdr"){
+            if(method!="customised"){
                 scores_test <- dBUMscore(fit=fit, method=method, fdr=fdr_test, scatter.bum=F)
-            }else if(method=="fdr"){
+            }else if(method=="customised"){
                 scores_test <- dFDRscore(pval, fdr.threshold=fdr_test, scatter=F)
             }
     
@@ -102,7 +105,7 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
             nsize_test <- vcount(module_test)
             
             if(verbose){
-                message(sprintf("\t\tFDR: %1.2e, corresponding to the network size (%d nodes)", fdr_test, nsize_test), appendLF=T)
+                message(sprintf("\t\tsignificance threshold: %1.2e, corresponding to the network size (%d nodes)", fdr_test, nsize_test), appendLF=T)
             }
             
             if(nsize_test >= nsize){
@@ -116,15 +119,15 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
             fdr_final <- fdr_rough
         }else{
             if(verbose){
-                message(sprintf("\tScanning FDR at finetune stage..."), appendLF=T)
+                message(sprintf("\tScanning significance threshold at finetune stage..."), appendLF=T)
             }
             ## at finetune phase
             fdr_final <- NULL
             for(fdr_test in seq(from=fdr_rough/10+fdr_rough/20,to=fdr_rough-fdr_rough/20,by=fdr_rough/20)){
             
-                if(method!="fdr"){
+                if(method!="customised"){
                     scores_test <- dBUMscore(fit=fit, method=method, fdr=fdr_test, scatter.bum=F)
-                }else if(method=="fdr"){
+                }else if(method=="customised"){
                     scores_test <- dFDRscore(pval, fdr.threshold=fdr_test, scatter=F)
                 }
             
@@ -132,7 +135,7 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
                 nsize_test <- vcount(module_test)
             
                 if(verbose){
-                    message(sprintf("\t\tFDR: %1.2e, corresponding to the network size (%d nodes)", fdr_test, nsize_test), appendLF=T)
+                    message(sprintf("\t\tsignificance threshold : %1.2e, corresponding to the network size (%d nodes)", fdr_test, nsize_test), appendLF=T)
                 }
             
                 if(nsize_test >= nsize){
@@ -146,15 +149,15 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
     
     if(is.null(fdr_final)){
         if(verbose){
-            message(sprintf("\tNo FDR threshold required"), appendLF=T)
+            message(sprintf("\tNo significance threshold required"), appendLF=T)
         }
     }else{
         if(verbose){
-            message(sprintf("\tFDR threshold: %1.2e", fdr_final), appendLF=T)
+            message(sprintf("\tsignificance threshold: %1.2e", fdr_final), appendLF=T)
         }
     }
     
-    if(method!="fdr"){
+    if(method!="customised"){
         if(verbose){
             message(sprintf("Third, calculate the scores according to the fitted BUM and FDR threshold (if any)..."), appendLF=T)
         }
@@ -164,11 +167,11 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
         }else{
             scores <- dBUMscore(fit=fit, method=method, fdr=fdr_final, scatter.bum=F)
         }
-    }else if(method=="fdr"){
+    }else if(method=="customised"){
         if(verbose){
-            message(sprintf("Third, calculate the scores according to the given fdr and the threshold (if any)..."), appendLF=T)
+            message(sprintf("Third, calculate the scores according to the input fdr (or p-value) and the threshold (if any)..."), appendLF=T)
         }
-        ## calculate the scores according to the fitted BUM and fdr threshold (fdr_final) 
+        ## calculate the scores according to the input fdr (or p-value) and the threshold (fdr_final) 
         if(plot){
             scores <- dFDRscore(pval, fdr.threshold=fdr_final, scatter=T)
         }else{
@@ -179,12 +182,12 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
     
     if(verbose){
         message(sprintf("\tAmongst %d scores, there are %d positives.", length(scores), sum(scores>0)), appendLF=T)
-        message(sprintf("Finally, find the subnetwork from the input network with %d nodes and %d edges...", vcount(g), ecount(g)), appendLF=T)
+        message(sprintf("Finally, find the subgraph from the input graph with %d nodes and %d edges...", vcount(g), ecount(g)), appendLF=T)
     }
-    ## find the module with the maximum score
-    module <- dNetFind(g, scores)
+    ## find the subgraph with the maximum score
+    subgraph <- dNetFind(g, scores)
     if(verbose){
-        message(sprintf("\tSize of the module: %d nodes and %d edges", vcount(module), ecount(module)), appendLF=T)
+        message(sprintf("\tSize of the subgraph: %d nodes and %d edges", vcount(subgraph), ecount(subgraph)), appendLF=T)
     }
     
     ####################################################################################
@@ -196,6 +199,6 @@ dNetPipeline <- function(g, pval, method=c("pdf","cdf","fdr"), fdr=NULL, nsize=N
     runTime <- as.numeric(difftime(strptime(endT, "%Y-%m-%d %H:%M:%S"), strptime(startT, "%Y-%m-%d %H:%M:%S"), units="secs"))
     message(paste(c("Runtime in total is: ",runTime," secs\n"), collapse=""), appendLF=T)
     
-    return(module)
+    return(subgraph)
 
 }
\ No newline at end of file
