@@ -87,7 +87,7 @@
 #' names(root.label) <- V(subg)[root]$name
 #' visDAG(g=subg, data=data, node.info="both", node.attrs=list(shape=root.shape,label=root.label))
 
-visDAG <- function (g, data=NULL, height=7, width=7, margin=rep(0.1,4), colormap=c("lightyellow-orange","yr","bwr","jet","gbr","wyr","br","rainbow","wb"), ncolors=40, zlim=NULL, colorbar=T, colorbar.fraction=0.1, newpage=T, layout.orientation=c("left_right","top_bottom","bottom_top","right_left"), node.info=c("none", "term_id", "term_name", "both", "full_term_name"), graph.node.attrs=NULL, graph.edge.attrs=NULL, node.attrs=NULL)
+visDAG <- function (g, data=NULL, height=7, width=7, margin=rep(0.1,4), colormap=c("lightyellow-orange","yr","bwr","jet","gbr","wyr","br","rainbow","wb")[1], ncolors=40, zlim=NULL, colorbar=T, colorbar.fraction=0.1, newpage=T, layout.orientation=c("left_right","top_bottom","bottom_top","right_left"), node.info=c("none", "term_id", "term_name", "both", "full_term_name"), graph.node.attrs=NULL, graph.edge.attrs=NULL, node.attrs=NULL)
 {
     
     ## match.arg matches arg against a table of candidate values as specified by choices, where NULL means to take the first one
